pub async fn refresh_move_source(
manager: &SessionManagerControl,
id: &str,
) -> Result<Option<ManagedSessionSnapshot>>Expand description
Refresh source state without turning a dead source harness into a Move prerequisite.
pub async fn refresh_move_source(
manager: &SessionManagerControl,
id: &str,
) -> Result<Option<ManagedSessionSnapshot>>Refresh source state without turning a dead source harness into a Move prerequisite.