load_stopped_subagents

Function load_stopped_subagents 

pub fn load_stopped_subagents(
    parent_session_id: &str,
) -> Result<Vec<StoppedSubagent>>
The sub-agents a suspend of this session stopped and its model has not been told about yet, in the order they were recorded.