pub type MaterializedTurnState = (MaterializedExecutionState, Option<MaterializedTurn>, Option<MaterializedTurnOutcome>);Expand description
Execution state, the running turn, and the last finished turn’s outcome.
pub type MaterializedTurnState = (MaterializedExecutionState, Option<MaterializedTurn>, Option<MaterializedTurnOutcome>);Execution state, the running turn, and the last finished turn’s outcome.