Module desktop

Module desktop 

Process-boundary protocol shared by mj and mj-desktop.

Structs

DesktopLaunch
Everything the native desktop process needs from the controller process.

Constants

DESKTOP_LAUNCH_PROTOCOL_VERSION

Functions

sibling_executable
Resolve a packaged companion beside the currently running executable.