pub enum ResumePlan {
InPlace,
RawToWorkspace,
WorkspaceToRaw,
}Expand description
What a resume has to do to the session record before it provisions.
Variants
InPlace
Keep the session in the representation it already has.
RawToWorkspace
Move a raw checkout session into a workspace target as a bundle session.
WorkspaceToRaw
Move a bundle session out of its workspace into a raw local worktree.