pub struct QuickBundleCreation {
pub config: HelConfig,
pub bundle_id: String,
}Expand description
The durable result of creating a quick bundle. The returned config is the same fresh config that was written, allowing a serving projection to publish the new bundle before acknowledging the request that created it.
Fields
config: HelConfigbundle_id: StringTrait Implementations