pub fn read_codex_transcript(path: &Path) -> Result<CodexTranscript>Expand description
Project a Codex rollout into the canonical transcript used by Hel chat.
pub fn read_codex_transcript(path: &Path) -> Result<CodexTranscript>Project a Codex rollout into the canonical transcript used by Hel chat.