pub struct LocatedNativeSession {
pub native_session_id: String,
pub source_path: PathBuf,
}Expand description
One native session located on disk, normalized across harnesses: the id
session/load takes and the file or directory its transcript is read from.
Fields
native_session_id: Stringsource_path: PathBufTrait Implementations
Sourceimpl Clone for LocatedNativeSession
impl Clone for LocatedNativeSession
Sourcefn clone(&self) -> LocatedNativeSession
fn clone(&self) -> LocatedNativeSession
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LocatedNativeSession
impl Debug for LocatedNativeSession
impl Eq for LocatedNativeSession
Sourceimpl PartialEq for LocatedNativeSession
impl PartialEq for LocatedNativeSession
impl StructuralPartialEq for LocatedNativeSession