pub struct BackgroundTaskStopRequest {
pub session_id: String,
pub background_task_id: String,
pub reply: Sender<Result<(), BackgroundTaskStopFailure>>,
}Expand description
A phone request to stop one currently projected background task.
This is intentionally not a ControllerAction. The request is already
validated against the current operational snapshot by the HTTP handler,
then the controller resolves the live session handle and waits for the
provider acknowledgement in a supervised task.
Fields
session_id: Stringbackground_task_id: Stringreply: Sender<Result<(), BackgroundTaskStopFailure>>Trait Implementations