pub struct ViewerMoveRecovery {Show 16 fields
pub operation_id: String,
pub source_profile_id: String,
pub source_target_template_id: String,
pub destination_profile_id: String,
pub destination_target_template_id: String,
pub phase: String,
pub queue: String,
pub clear_resource_allocation: bool,
pub source_additional_mounts: Vec<AdditionalMount>,
pub source_resource_allocation: Option<SessionResourceAllocation>,
pub destination_additional_mounts: Vec<AdditionalMount>,
pub destination_resource_allocation: Option<SessionResourceAllocation>,
pub checkpoint_retained: bool,
pub destination_ready: bool,
pub queue_admission_started: bool,
pub queue_admission_finished: bool,
}Fields
operation_id: Stringsource_profile_id: Stringsource_target_template_id: Stringdestination_profile_id: Stringdestination_target_template_id: Stringphase: Stringqueue: Stringclear_resource_allocation: boolsource_additional_mounts: Vec<AdditionalMount>The source settings are retained so Resume cannot silently inherit a partially converted destination record after a failed Move.
source_resource_allocation: Option<SessionResourceAllocation>destination_additional_mounts: Vec<AdditionalMount>The exact destination settings are needed when a queue admission checkpoint pins retry to the already-provisioned destination.
destination_resource_allocation: Option<SessionResourceAllocation>checkpoint_retained: booldestination_ready: boolqueue_admission_started: boolqueue_admission_finished: boolImplementations
Sourceimpl ViewerMoveRecovery
impl ViewerMoveRecovery
pub fn from_operation(operation: &MoveOperation) -> Option<Self>