pub struct ViewerTarget {
pub id: String,
pub kind: String,
pub requires_project_directory: bool,
pub recent_project_directories: Vec<String>,
}Fields
id: Stringkind: Stringrequires_project_directory: boolrecent_project_directories: Vec<String>Recent raw project directories for this target’s physical host. Managed targets intentionally publish an empty list because they select a configured bundle rather than a host checkout.