optimize_image

Function optimize_image 

pub fn optimize_image(bytes: &[u8]) -> Result<OptimizedImage, Error>
Decode and optimize a JPEG, PNG, or WebP image.

Images larger than the output budget are recompressed and progressively resized. EXIF orientation is applied before deciding the output dimensions.