pub fn scan_codex_sessions(
home: &Path,
report: impl FnMut(SessionScanProgress<LocatedCodexSession>),
) -> Result<()>Expand description
Scan native Codex sessions newest first, reporting after every candidate file.
pub fn scan_codex_sessions(
home: &Path,
report: impl FnMut(SessionScanProgress<LocatedCodexSession>),
) -> Result<()>Scan native Codex sessions newest first, reporting after every candidate file.