pub struct LaunchRepository {
pub id: String,
pub github: Option<String>,
pub destination: String,
}Fields
id: Stringgithub: Option<String>The GitHub source, when this repository has one. A repository sourced from a local directory publishes nothing here, because that source is a path on the controller.
destination: StringTrait Implementations
Sourceimpl Clone for LaunchRepository
impl Clone for LaunchRepository
Sourceimpl Debug for LaunchRepository
impl Debug for LaunchRepository
Sourceimpl<'de> Deserialize<'de> for LaunchRepository
impl<'de> Deserialize<'de> for LaunchRepository
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LaunchRepository
Sourceimpl PartialEq for LaunchRepository
impl PartialEq for LaunchRepository
Sourceimpl Serialize for LaunchRepository
impl Serialize for LaunchRepository
impl StructuralPartialEq for LaunchRepository