pub struct SessionMessageResponse {
pub session_id: String,
pub via: String,
pub turn_id: Option<u64>,
/* private fields */
}Expand description
Result of delivering one message to a session, either through its mailbox or as a queued prompt for an older worker.
Fields
session_id: Stringvia: Stringturn_id: Option<u64>Trait Implementations
Sourceimpl Clone for SessionMessageResponse
impl Clone for SessionMessageResponse
Sourceimpl Debug for SessionMessageResponse
impl Debug for SessionMessageResponse
Sourceimpl<'de> Deserialize<'de> for SessionMessageResponse
impl<'de> Deserialize<'de> for SessionMessageResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SessionMessageResponse
Sourceimpl PartialEq for SessionMessageResponse
impl PartialEq for SessionMessageResponse
Sourceimpl Serialize for SessionMessageResponse
impl Serialize for SessionMessageResponse
impl StructuralPartialEq for SessionMessageResponse