pub struct StartSessionResponse {
pub session_id: String,
pub turn_id: Option<u64>,
}Fields
session_id: Stringturn_id: Option<u64>The turn the follow-up prompt was accepted as, once it has been submitted. Creation answers before that, so it is usually absent.