pub struct WaitRequest {
pub return_on_input: bool,
pub turn_id: Option<u64>,
pub timeout_secs: Option<u64>,
}Fields
return_on_input: boolReturn when the harness presents a structured input request.
turn_id: Option<u64>Wait for this specific prompt. Absent means “wait until the session is idle with nothing queued”, which is what a caller that lost its turn id wants.
timeout_secs: Option<u64>Trait Implementations
Sourceimpl Clone for WaitRequest
impl Clone for WaitRequest
Sourcefn clone(&self) -> WaitRequest
fn clone(&self) -> WaitRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WaitRequest
impl Debug for WaitRequest
Sourceimpl Default for WaitRequest
impl Default for WaitRequest
Sourcefn default() -> WaitRequest
fn default() -> WaitRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for WaitRequest
impl<'de> Deserialize<'de> for WaitRequest
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for WaitRequest
impl PartialEq for WaitRequest
Sourceimpl Serialize for WaitRequest
impl Serialize for WaitRequest
impl StructuralPartialEq for WaitRequest