pub fn actionable_errors(checks: &[DoctorCheck]) -> Vec<String>Expand description
Welcome displays errors and concrete remedies, without successful checks or warnings about optional built-in runtimes and background image downloads.
pub fn actionable_errors(checks: &[DoctorCheck]) -> Vec<String>Welcome displays errors and concrete remedies, without successful checks or warnings about optional built-in runtimes and background image downloads.