pub struct CancellableProcessExecutor { /* private fields */ }Implementations
Sourceimpl CancellableProcessExecutor
impl CancellableProcessExecutor
pub fn new(cancelled: Arc<Atomic<bool>>) -> CancellableProcessExecutor
pub fn is_cancelled(&self) -> bool
pub fn with_timeout(timeout: Duration) -> CancellableProcessExecutor
Sourcepub fn with_deadline(self, timeout: Duration) -> CancellableProcessExecutor
pub fn with_deadline(self, timeout: Duration) -> CancellableProcessExecutor
Bounds an existing flag-based executor with a deadline, so a wedged child becomes a reported failure instead of running forever.