pub struct DeploymentCapacityTarget {
pub id: String,
pub host: String,
pub target_ids: Vec<String>,
pub kind: DeploymentCapacityKind,
pub local: bool,
pub probes: Vec<CommandSpec>,
pub probe_error: Option<String>,
}Fields
id: Stringhost: Stringtarget_ids: Vec<String>kind: DeploymentCapacityKindlocal: boolprobes: Vec<CommandSpec>Alternative commands for a host, or one command per live AWS instance.
probe_error: Option<String>Prevents a partial AWS fleet sample when one live instance cannot be probed yet.