pub struct RecordedTarget<'a> {
pub locator: &'a TargetLocator,
pub runtime: Option<&'a TargetRuntimeSettings>,
pub session_id: &'a str,
}Expand description
A provisioned target paired with its durable access settings.
Fields
locator: &'a TargetLocatorruntime: Option<&'a TargetRuntimeSettings>session_id: &'a strTrait Implementations
Sourceimpl TryFrom<RecordedTarget<'_>> for TargetLocator
impl TryFrom<RecordedTarget<'_>> for TargetLocator
Sourcetype Error = TargetConversionError
type Error = TargetConversionError
The type returned in the event of a conversion error.
Sourcefn try_from(
stored: RecordedTarget<'_>,
) -> Result<TargetLocator, <TargetLocator as TryFrom<RecordedTarget<'_>>>::Error>
fn try_from( stored: RecordedTarget<'_>, ) -> Result<TargetLocator, <TargetLocator as TryFrom<RecordedTarget<'_>>>::Error>
Performs the conversion.