pub struct TargetPlatform {
pub os: TargetOs,
pub architecture: &'static str,
}Expand description
Platform of the execution boundary, which may differ from both the controller and the host of a Linux container.
Fields
os: TargetOsarchitecture: &'static strImplementations