mark_session_worker_connected

Function mark_session_worker_connected 

pub fn mark_session_worker_connected(
    session_id: &str,
    native_session_id: Option<&str>,
    updated_at: &str,
) -> Result<()>
Commit the successful handshake for a newly provisioned worker without replacing checkpoint or display metadata owned by other controller tasks.