pub fn save_checkpointed_session(session: &SessionRecord) -> Result<()>Expand description
Install a lifecycle transition together with the checkpoint it just verified and the harness session id that produced it.
pub fn save_checkpointed_session(session: &SessionRecord) -> Result<()>Install a lifecycle transition together with the checkpoint it just verified and the harness session id that produced it.