pub struct WaitObservation {
pub background_work: Option<ApiBackgroundWork>,
pub pending_elicitations: Vec<ElicitationRequest>,
pub lifecycle: Option<ViewerLifecycleCategory>,
pub launch_failed: bool,
pub launch_error: Option<String>,
pub execution: MaterializedExecutionState,
pub active_turn: Option<MaterializedTurn>,
pub last_turn_outcome: Option<MaterializedTurnOutcome>,
pub queued: usize,
pub capacity_retry: Option<CapacityRetry>,
pub start_status: Option<StartStatus>,
}Expand description
Everything one pass of the wait loop knows about a session.
Fields
background_work: Option<ApiBackgroundWork>pending_elicitations: Vec<ElicitationRequest>lifecycle: Option<ViewerLifecycleCategory>launch_failed: boolA recorded launch failure names this session.
launch_error: Option<String>Why the launch failed, when a reason was recorded.
execution: MaterializedExecutionStateactive_turn: Option<MaterializedTurn>last_turn_outcome: Option<MaterializedTurnOutcome>queued: usizecapacity_retry: Option<CapacityRetry>start_status: Option<StartStatus>Trait Implementations
Sourceimpl Clone for WaitObservation
impl Clone for WaitObservation
Sourcefn clone(&self) -> WaitObservation
fn clone(&self) -> WaitObservation
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WaitObservation
impl Debug for WaitObservation
Sourceimpl Default for WaitObservation
impl Default for WaitObservation
Sourcefn default() -> WaitObservation
fn default() -> WaitObservation
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for WaitObservation
impl PartialEq for WaitObservation
impl StructuralPartialEq for WaitObservation