pub fn run_setup(
config_path: &Path,
instance_data: &Path,
force: bool,
executor: &impl CommandExecutor,
cancelled: &dyn Fn() -> bool,
accepted: impl FnOnce(),
) -> Result<Option<SetupReport>>Expand description
Returns None when automatic setup belongs to an existing installation.
The accepted callback runs under the setup lock, before discovery starts.